@@ -38,14 +38,14 @@ class WebCoverageService_1_0_0(WCSBase):
         else:
             raise KeyError("No content named %s" % name)
 
-    def __init__(self, url, xml, cookies, auth=None, timeout=30):
-        super(WebCoverageService_1_0_0, self).__init__(auth)
+    def __init__(self, url, xml, cookies, auth=None, timeout=30, headers=None):
+        super(WebCoverageService_1_0_0, self).__init__(auth, headers=headers)
         self.version = '1.0.0'
         self.url = url
         self.cookies = cookies
         self.timeout = timeout
         # initialize from saved capability document or access the server
-        reader = WCSCapabilitiesReader(self.version, self.cookies, self.auth)
+        reader = WCSCapabilitiesReader(self.version, self.cookies, self.auth, headers=self.headers)
         if xml:
             self._capabilities = reader.readString(xml)
         else:
@@ -155,7 +155,7 @@ class WebCoverageService_1_0_0(WCSBase):
         data = urlencode(request)
         log.debug('WCS 1.0.0 DEBUG: Second part of URL: %s' % data)
 
-        u = openURL(base_url, data, method, self.cookies, auth=self.auth, timeout=timeout)
+        u = openURL(base_url, data, method, self.cookies, auth=self.auth, timeout=timeout, headers=self.headers)
         return u
 
     def getOperationByName(self, name):
