@@ -171,6 +171,8 @@ class MD_Metadata(object):
             val = md.find(util.nspath_eval('gmi:acquisitionInformation/gmi:MI_AcquisitionInformation', namespaces))
             if val is not None:
                 self.acquisition = MI_AcquisitionInformation(val)
+            else:
+                self.acquisition = None
 
     def get_default_locale(self):
         """ get default gmd:PT_Locale based on gmd:language """
@@ -323,6 +325,13 @@ class MD_Keywords(object):
 
                 thesaurus = val.find(util.nspath_eval('gmd:title/gco:CharacterString', namespaces))
                 self.thesaurus['title'] = util.testXMLValue(thesaurus)
+                self.thesaurus['url'] = None
+
+                if self.thesaurus['title'] is None:  # try gmx:Anchor
+                    t = val.find(util.nspath_eval('gmd:title/gmx:Anchor', namespaces))
+                    if t is not None:
+                        self.thesaurus['title'] = util.testXMLValue(t)
+                        self.thesaurus['url'] = t.attrib.get(util.nspath_eval('xlink:href', namespaces))
 
                 thesaurus = val.find(util.nspath_eval('gmd:date/gmd:CI_Date/gmd:date/gco:Date', namespaces))
                 self.thesaurus['date'] = util.testXMLValue(thesaurus)
